# TestCaseUpdatePolicyDto


## Enum

* `FROM_TEST_CASE` (value: `'from_test_case'`)

* `FROM_TEST_RESULT` (value: `'from_test_result'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


